Installation
============

.. tab-set::

    .. tab-item:: Linux

        The recommended installation is to:
    
        .. code-block:: console
    
            pip install auxi-mpp


    .. tab-item:: macOS

      The recommended installation is to:

        .. code-block:: console

            pip install auxi-mpp


    .. tab-item:: Windows
        
        The recommended installation is to:

        .. code-block:: console

            pip install auxi-mpp